#! /usr/bin/env node
"use strict";

var _commandLineArgs = _interopRequireDefault(require("command-line-args"));

var _commandLineUsage = _interopRequireDefault(require("command-line-usage"));

var _swig = _interopRequireDefault(require("swig"));

var _TemplateFactory = _interopRequireDefault(require("./TemplateFactory"));

var _RunCommand = _interopRequireDefault(require("./RunCommand"));

var _cliOptions = require("./config/cli-options");

var _swigFilters = _interopRequireDefault(require("./config/swig-filters"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

(0, _swigFilters["default"])(_swig["default"]);
var mainCli = (0, _commandLineArgs["default"])(_cliOptions.mainList, {
  stopAtFirstUnknown: true
});
var mainOptions = mainCli.options;
var mainArgv = mainCli._unknown || []; // Generate commands

if (mainOptions.generate) {
  var generateCli = (0, _commandLineArgs["default"])(_cliOptions.generateList, {
    argv: mainArgv,
    stopAtFirstUnknown: true
  });
  var generateOptions = generateCli.Generate; //let generateArgv = generateCli._unknown || [];

  if (generateOptions.hasOwnProperty('component')) {
    _TemplateFactory["default"].createTemplateFor(generateOptions);

    console.log('Component Generated.');
  } else if (generateOptions.hasOwnProperty('hook')) {
    _TemplateFactory["default"].createTemplateFor(generateOptions);

    console.log('Hook Generated.');
  } else if (mainOptions.help || generateOptions.help) {
    console.log((0, _commandLineUsage["default"])({
      header: 'Generate Options',
      optionList: _cliOptions.generateList
    }));
  } else {
    console.log('Unknown Parameter');
    console.log((0, _commandLineUsage["default"])({
      header: 'Generate Options',
      optionList: _cliOptions.generateList
    }));
  }
} else if (mainOptions.rtk) {
  // redux toolkit commands
  var rtkCli = (0, _commandLineArgs["default"])(_cliOptions.rtkList, {
    argv: mainArgv,
    stopAtFirstUnknown: true
  });
  var rtkOptions = rtkCli.rtk;

  if (rtkOptions.hasOwnProperty('store')) {
    _TemplateFactory["default"].createTemplateFor(rtkOptions);

    console.log('Store Generated.');
  } else if (rtkOptions.hasOwnProperty('slice')) {
    _TemplateFactory["default"].createTemplateFor(rtkOptions);

    console.log('Slice Generated.');
  } else if (mainOptions.help || rtkOptions.help) {
    console.log((0, _commandLineUsage["default"])({
      header: 'RTK Options',
      optionList: _cliOptions.rtkList
    }));
  } else {
    console.log('Unknown Parameter');
    console.log((0, _commandLineUsage["default"])({
      header: 'RTK Options',
      optionList: _cliOptions.rtkList
    }));
  }
} // Serve commands
else if (mainOptions.run) {
  var serveCli = (0, _commandLineArgs["default"])(_cliOptions.serveList, {
    argv: mainArgv,
    stopAtFirstUnknown: true
  });
  var serveOptions = serveCli.Run;

  if (mainOptions.hasOwnProperty('help') || serveOptions && serveOptions.hasOwnProperty('help')) {
    console.log((0, _commandLineUsage["default"])({
      header: 'Run Options',
      optionList: _cliOptions.serveList
    }));
  } else {
    _RunCommand["default"].serveCommand(serveOptions);
  }
} // Build commands
else if (mainOptions.build) {
  _RunCommand["default"].buildCommand();
} // Main help
else if (mainOptions.help) {
  console.log((0, _commandLineUsage["default"])({
    header: 'Main Options',
    optionList: _cliOptions.mainList
  }));
} else {
  console.log('Unknown Parameter');
  console.log((0, _commandLineUsage["default"])({
    header: 'Main Options',
    optionList: _cliOptions.mainList
  }));
}